==> v2.1.1.tar.gz: zyos_go_order_relate_rule/svc/svc_block_star_chain_settlement.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/cache"
	"fmt"
	"xorm.io/xorm"
)

// GetUserCoinAmount 获取用户虚拟积分余额
func GetUserCoinAmount(session *xorm.Session, masterId string, coinId, uid int) (amount string, err error) {
	redisKey := fmt.Sprintf(md.UserVirtualAmountRedisKey, masterId, coinId, uid)
	amount, err = cache.GetString(redisKey)
	if err != nil {
		if err.Error() == "redigo: nil returned" {
			userVirtualAmount, err := db.GetUserVirtualWalletWithSession(session, uid, coinId)
			//if err != nil {
			//	return amount, err
			//}
			if userVirtualAmount == nil {
				amount = "0"
			} else {
				amount = userVirtualAmount.Amount
			}
			//将获取到的余额值缓存至redis
			_ = SetCacheUserVirtualAmount(session, masterId, amount, coinId, uid, false)
			return amount, nil
		}
		return amount, err
	}
	return amount, nil
}

// SetCacheUserVirtualAmount 设置缓存的用户虚拟币积分余额
func SetCacheUserVirtualAmount(session *xorm.Session, masterId, amount string, coinId, uid int, isUpdateDb bool) error {
	redisKey := fmt.Sprintf(md.UserVirtualAmountRedisKey, masterId, coinId, uid)
	if isUpdateDb {
		_, err := session.Where("uid=?", uid).And("coin_id=?", coinId).Update(model.UserVirtualAmount{
			Uid:    uid,
			CoinId: coinId,
			Amount: amount,
		})
		if err != nil {
			return err
		}
	}
	//_, err := cache.Set(redisKey, int64(utils.StrToFloat64(amount)))
	//TODO::默认缓存1小时 (先调整为 10 min)
	_, err := cache.SetEx(redisKey, int64(zhios_order_relate_utils.StrToFloat64(amount)), 60*60*0.1)
	if err != nil {
		return err
	}
	return nil
}

==> v3.0.9.tar.gz: zyos_go_order_relate_rule/svc/svc_block_star_chain_settlement.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db/model"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/cache"
	"fmt"
	"xorm.io/xorm"
)

// GetUserCoinAmount 获取用户虚拟积分余额
func GetUserCoinAmount(session *xorm.Session, masterId string, coinId, uid int) (amount string, err error) {
	redisKey := fmt.Sprintf(md.UserVirtualAmountRedisKey, masterId, coinId, uid)
	amount, err = cache.GetString(redisKey)
	if err != nil {
		if err.Error() == "redigo: nil returned" {
			userVirtualAmount, err := db.GetUserVirtualWalletWithSession(session, uid, coinId)
			if err != nil {
				return amount, err
			}
			if userVirtualAmount == nil {
				amount = "0"
			} else {
				amount = userVirtualAmount.Amount
			}
			//将获取到的余额值缓存至redis
			_ = SetCacheUserVirtualAmount(session, masterId, amount, coinId, uid, false)
			return amount, nil
		}
		return amount, err
	}
	return amount, nil
}

// SetCacheUserVirtualAmount 设置缓存的用户虚拟币积分余额
func SetCacheUserVirtualAmount(session *xorm.Session, masterId, amount string, coinId, uid int, isUpdateDb bool) error {
	redisKey := fmt.Sprintf(md.UserVirtualAmountRedisKey, masterId, coinId, uid)
	if isUpdateDb {
		_, err := session.Where("uid=?", uid).And("coin_id=?", coinId).Update(model.UserVirtualAmount{
			Uid:    uid,
			CoinId: coinId,
			Amount: amount,
		})
		if err != nil {
			return err
		}
	}
	//_, err := cache.Set(redisKey, int64(utils.StrToFloat64(amount)))
	//TODO::默认缓存1小时 (先调整为 5 min)
	_, err := cache.SetEx(redisKey, int64(zhios_order_relate_utils.StrToFloat64(amount)), 60*5)
	if err != nil {
		return err
	}
	return nil
}
